@@ -13,23 +13,34 @@ doi_table = Table(
     'doi',
     meta.metadata,
     Column('identifier', types.UnicodeText, primary_key=True),
-    Column('package_id', types.UnicodeText,
-           ForeignKey('package.id', onupdate='CASCADE', ondelete='CASCADE'),
-           nullable=False, unique=True),
+    Column(
+        'package_id',
+        types.UnicodeText,
+        ForeignKey('package.id', onupdate='CASCADE', ondelete='CASCADE'),
+        nullable=False,
+        unique=True,
+    ),
     # Date DOI was published to DataCite
     Column('published', types.DateTime, nullable=True),
 )
 
 
 class DOI(DomainObject):
-    '''DOI Object'''
+    """
+    DOI Object.
+    """
+
     pass
 
 
-meta.mapper(DOI, doi_table, properties={
-    'dataset': relation(
-        Package,
-        backref=backref('doi', cascade='all, delete-orphan'),
-        primaryjoin=doi_table.c.package_id.__eq__(Package.id)
-    )
-})
+meta.mapper(
+    DOI,
+    doi_table,
+    properties={
+        'dataset': relation(
+            Package,
+            backref=backref('doi', cascade='all, delete-orphan'),
+            primaryjoin=doi_table.c.package_id.__eq__(Package.id),
+        )
+    },
+)
